@@ -34,7 +34,7 @@ class Environment(BaseModel):
 
         :return: base url
         """
-        return os.getenv("XAI_API_URL")
+        return os.getenv("XAI_API_URL", "https://api-m.aryaxai.com")
 
     def get_debug(self) -> bool:
         """get debug flag
