@@ -25,6 +25,8 @@ DELETE_DATA_FILE_URI = f"{API_VERSION}/project/delete_data"
 ALL_DATA_FILE_URI = f"{API_VERSION}/project/get_all_uploaded_files"
 UPLOAD_DATA_URI = f"{API_VERSION}/project/upload_data"
 UPLOAD_DATA_WITH_CHECK_URI = f"{API_VERSION}/project/upload_data_with_check"
+UPLOAD_MODEL_URI = f"{API_VERSION}/project/upload_model"
+GET_MODEL_TYPES_URI = f"{API_VERSION}/project/get_model_types"
 GET_DATA_SUMMARY_URI = f"{API_VERSION}/project/data_summary"
 GET_DATA_DIAGNOSIS_URI = f"{API_VERSION}/project/get_data_diagnosis"
 DATA_DRFIT_DIAGNOSIS_URI = f"{API_VERSION}/project/run_data_drift_diagnosis"
@@ -75,3 +77,29 @@ CREATE_TRIGGER_URI = f"{API_VERSION}/triggers/update_triggers"
 DELETE_TRIGGER_URI = f"{API_VERSION}/triggers/update_triggers"
 EXECUTED_TRIGGER_URI = f"{API_VERSION}/triggers/get_executed_triggers"
 GET_EXECUTED_TRIGGER_INFO = f"{API_VERSION}/triggers/get_trigger_details"
+
+# Synthetic AI
+GET_SYNTHETIC_MODEL_PARAMS_URI = (
+    f"{API_VERSION}/synthetics/get_synthetic_model_parameters"
+)
+TRAIN_SYNTHETIC_MODEL_URI = f"{API_VERSION}/synthetics/train_synthetic_model"
+GET_SYNTHETIC_MODELS_URI = f"{API_VERSION}/synthetics/get_synthetics_models"
+DELETE_SYNTHETIC_MODEL_URI = f"{API_VERSION}/synthetics/delete_synthetic_model"
+GET_SYNTHETIC_MODEL_DETAILS_URI = (
+    f"{API_VERSION}/synthetics/get_synthetic_model_details"
+)
+GET_SYNTHETIC_TRAINING_LOGS_URI = f"{API_VERSION}/synthetics/get_training_logs"
+GENERATE_SYNTHETIC_DATA_URI = f"{API_VERSION}/synthetics/generate_synthetic_data"
+GENERATE_ANONYMITY_SCORE_URI = f"{API_VERSION}/synthetics/generate_anonimity_score"
+GET_ANONYMITY_SCORE_URI = f"{API_VERSION}/synthetics/get_anonimity_score"
+
+GET_SYNTHETIC_DATA_TAGS_URI = f"{API_VERSION}/synthetics/get_synthetic_data_tags"
+DOWNLOAD_SYNTHETIC_DATA_URI = f"{API_VERSION}/synthetics/download_synthetic_data"
+DELETE_SYNTHETIC_TAG_URI = f"{API_VERSION}/project/delete_data_with_filter"
+
+CREATE_SYNTHETIC_PROMPT_URI = f"{API_VERSION}/synthetics/create_synthetic_prompts"
+UPDATE_SYNTHETIC_PROMPT_URI = f"{API_VERSION}/synthetics/synthetic_prompts_update"
+GET_SYNTHETIC_PROMPT_URI = f"{API_VERSION}/synthetics/get_synthetics_promts"
+
+# Events
+POLL_EVENTS = f"{API_VERSION}/events/poll"
